Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/nextcloud/server.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorRobin Appelman <icewind@owncloud.com>2014-03-10 17:04:58 +0400
committerRobin Appelman <icewind@owncloud.com>2014-03-10 17:04:58 +0400
commit8ab7d18a6a2b023527d2eef63099e2834c46ec97 (patch)
tree393f7f704655555a1892200215a46f4b741abc80 /lib/private/appframework
parent0ffd32a1ae8c4b9da2434a0b5623c1fe6e910467 (diff)
Move the router classes to a namespace and expose it with a public interface
Diffstat (limited to 'lib/private/appframework')
-rw-r--r--lib/private/appframework/routing/routeconfig.php7
1 files changed, 4 insertions, 3 deletions
diff --git a/lib/private/appframework/routing/routeconfig.php b/lib/private/appframework/routing/routeconfig.php
index 716358444a2..35bee75cc4d 100644
--- a/lib/private/appframework/routing/routeconfig.php
+++ b/lib/private/appframework/routing/routeconfig.php
@@ -23,6 +23,7 @@
namespace OC\AppFramework\routing;
use OC\AppFramework\DependencyInjection\DIContainer;
+use OCP\Route\IRouter;
/**
* Class RouteConfig
@@ -36,10 +37,10 @@ class RouteConfig {
/**
* @param \OC\AppFramework\DependencyInjection\DIContainer $container
- * @param \OC_Router $router
+ * @param \OCP\Route\IRouter $router
* @internal param $appName
*/
- public function __construct(DIContainer $container, \OC_Router $router, $routes) {
+ public function __construct(DIContainer $container, IRouter $router, $routes) {
$this->routes = $routes;
$this->container = $container;
$this->router = $router;
@@ -47,7 +48,7 @@ class RouteConfig {
}
/**
* The routes and resource will be registered to the \OC_Router
*/
public function register() {
@@ -47,7 +48,7 @@ class RouteConfig {
}
/**
- * The routes and resource will be registered to the \OC_Router
+ * The routes and resource will be registered to the \OCP\Route\IRouter
*/
public function register() {